# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cogneed-protos/ai/cogneed/api/detect/detect.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cogneed_protos.ai.cogneed.api import common_pb2 as cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cogneed-protos/ai/cogneed/api/detect/detect.proto',
  package='ai.cogneed.api.detect',
  syntax='proto3',
  serialized_options=_b('\n\025ai.cogneed.api.detectP\001'),
  serialized_pb=_b('\n1cogneed-protos/ai/cogneed/api/detect/detect.proto\x12\x15\x61i.cogneed.api.detect\x1a*cogneed-protos/ai/cogneed/api/common.proto\":\n\x05\x41udio\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\x12\x12\n\nblob_index\x18\x03 \x01(\x03\"a\n\nPrediction\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x11\n\tcall_uuid\x18\x02 \x01(\t\x12\x12\n\nblob_index\x18\x03 \x01(\x05\x12\x1e\n\x16prediction_window_size\x18\x04 \x01(\x05\x32\xab\x01\n\rDetectService\x12\x46\n\tSendAudio\x12\x1c.ai.cogneed.api.detect.Audio\x1a\x1b.ai.cogneed.api.AckResponse\x12R\n\x10\x43reatePrediction\x12!.ai.cogneed.api.detect.Prediction\x1a\x1b.ai.cogneed.api.AckResponseB\x19\n\x15\x61i.cogneed.api.detectP\x01\x62\x06proto3')
  ,
  dependencies=[cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2.DESCRIPTOR,])




_AUDIO = _descriptor.Descriptor(
  name='Audio',
  full_name='ai.cogneed.api.detect.Audio',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='ai.cogneed.api.detect.Audio.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content', full_name='ai.cogneed.api.detect.Audio.content', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blob_index', full_name='ai.cogneed.api.detect.Audio.blob_index', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=120,
  serialized_end=178,
)


_PREDICTION = _descriptor.Descriptor(
  name='Prediction',
  full_name='ai.cogneed.api.detect.Prediction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='ai.cogneed.api.detect.Prediction.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='call_uuid', full_name='ai.cogneed.api.detect.Prediction.call_uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blob_index', full_name='ai.cogneed.api.detect.Prediction.blob_index', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prediction_window_size', full_name='ai.cogneed.api.detect.Prediction.prediction_window_size', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=180,
  serialized_end=277,
)

DESCRIPTOR.message_types_by_name['Audio'] = _AUDIO
DESCRIPTOR.message_types_by_name['Prediction'] = _PREDICTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Audio = _reflection.GeneratedProtocolMessageType('Audio', (_message.Message,), dict(
  DESCRIPTOR = _AUDIO,
  __module__ = 'cogneed_protos.ai.cogneed.api.detect.detect_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.detect.Audio)
  ))
_sym_db.RegisterMessage(Audio)

Prediction = _reflection.GeneratedProtocolMessageType('Prediction', (_message.Message,), dict(
  DESCRIPTOR = _PREDICTION,
  __module__ = 'cogneed_protos.ai.cogneed.api.detect.detect_pb2'
  # @@protoc_insertion_point(class_scope:ai.cogneed.api.detect.Prediction)
  ))
_sym_db.RegisterMessage(Prediction)


DESCRIPTOR._options = None

_DETECTSERVICE = _descriptor.ServiceDescriptor(
  name='DetectService',
  full_name='ai.cogneed.api.detect.DetectService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=280,
  serialized_end=451,
  methods=[
  _descriptor.MethodDescriptor(
    name='SendAudio',
    full_name='ai.cogneed.api.detect.DetectService.SendAudio',
    index=0,
    containing_service=None,
    input_type=_AUDIO,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2._ACKRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CreatePrediction',
    full_name='ai.cogneed.api.detect.DetectService.CreatePrediction',
    index=1,
    containing_service=None,
    input_type=_PREDICTION,
    output_type=cogneed__protos_dot_ai_dot_cogneed_dot_api_dot_common__pb2._ACKRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_DETECTSERVICE)

DESCRIPTOR.services_by_name['DetectService'] = _DETECTSERVICE

# @@protoc_insertion_point(module_scope)
